@@ -293,7 +293,7 @@ sub compile {
     my $header = delete $self->{header};
     my $footer = delete $self->{footer};
 
-    if(!$args{from_include}) {
+    if(!$args{omit_augment}) {
         if($header) {
             substr $input, 0, 0, $self->_cat_files($header);
         }
