@@ -29,5 +29,19 @@ __END__
 
 Text::Xslate::HashWithDefault - Helper class to fill in default values
 
+=head1 SYNOPSIS
+
+    use Text::Xslate::Util qw(hash_with_default);
+
+    my $hash_ref = hash_with_default({ }, sub { "FILLME('@_')" });
+    print $hash_ref->{foo}; # FILLME('foo')
+
+=head1 DESCRIPTION
+
+This is a helper class to provide C<hash_with_default()> functionality,
+which is useful for debugging.
+
+See L<Text::Xslate::Manual::Debugging> for details.
+
 =cut
 
